
/// "coupl_eff.c++"

/// "WARNING"
// **************************************************************************
// **************************************************************************
/*
                      SINGLE MODE OPTICAL FIBER COUPLING

     This program was thinked and realised by Xavier Outhier at the 
   Czech Thechnical University of Prague (Czech Republic) at the Faculty
   of Nuclear Physics in the department of Physical Electronics.

      This program was created in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

     Please contact me when you use it for your own and give me your
   impression about it (facility of use, bugs,...). Here is my e-mail
                      d2set@multimania.com
	  (precise in the subject or body of message to Xavier Outhier)
	      You can also visit the web site of D2SET association
		          http://www.multimania.com/d2set/


                                                Prague, 29th May 1997

                                                Xavier Outhier

*/
// **************************************************************************
// **************************************************************************
//f

/*************************************************************************/
//ce
//ce  NAME OF FILE            : coupl_eff.c++
//ce  VERSION                 : 1.6
//ce  DATE OF CREATION        : 16/06/1997 (Xavier)
//ce  LAST MODIFICATION ON    : 04/08/1997 (Xavier)
//ce  LAST CORRECTION ON      : 31/07/1997 (Xavier)
//ce  COMPATIBILITY           : 1.0
//ce  STAGE OF VERIFICATION   : none
//ce  DESCRIPTION OF THE FILE : Contains functions for computation of coupling
//ce    efficiency based on the article: "Coupling efficiency of optics in
//ce    single-mode fiber components", R. E. Wagner and W. J. Tomlinson,
//ce    August 1982, Vol. 21 N0. 15, Applied Optics.
//ce    And also the transmission power coefficient that is to be multiplied
//ce    to the coupling efficiency previously found.
//ce
/*************************************************************************/

/*************************************************************************/
//cm
//cm  List  of modifications :
//cm
//cm   v1.1, 02/07/1997, Xavier:
//cm    # Conformity with the new definition structure of bound
//cm
//cm   v1.2, 04/07/1997, Xavier:
//cm    # Suppression of x_inf, x_sup, y_inf and y_sup
//cm
//cm   v1.3, 07/07/1997, Xavier:
//cm    # Add of output in differents files
//cm
//cm   v1.4, 22/07/1997, Xavier:
//cm    # Field computation in the whole rectangular domain
//cm
/*************************************************************************/

/*************************************************************************/
//cc
//cc  List  of corrections :
//cc
//cc   v1.0, 17/06/1997, Xavier:
//cc    # Integration formula
//cc
//cc   v1.2, 04/07/1997, Xavier:
//cc    # Normalization of the right form now! Checked.
//cc
//cc   v1.5, 22/07/1997, Xavier:
//cc    # increment x and y in coupl_eff_formula and in  dbl_cmplx_integral
//cc
//cc   v1.6, 31/07/1997, Xavier:
//cc    # deallocation of memory with only one free() command
//cc
/*************************************************************************/

/// "includes"
#include <complex.h>
#include <stdlib.h>
#include <fstream.h>
#include "typedef.h"
#include "memories.h"
#include "coupl_eff.h"

//f

/// "defines"
// macros for easier using of matrixalloc
#define dmatrix(m,n) ((double**)matrixalloc(m,n,sizeof(double)))
#define cmatrix(m,n) ((complex**)matrixalloc(m,n,sizeof(complex)))
//f

/// "coupl_eff_formula"
/*************************************************************************/
//cf
//cf  Name of the function        : coupl_eff_formula
//cf  Version                     : 0.5
//cf  Date of creation            : 16/06/1997 (Xavier)
//cf  Last modification on        : 22/07/1997 (Xavier)
//cf  Last correction on          : 31/07/1997 (Xavier)
//cf  Compatibility               : 1.0
//cf  Verification Stage          : (see below)
//cf  Description of the function : Compute coupling efficiency in a fiber
//cf    through a thins lens and from another fiber.
//cf    Formula(5) from "Coupling efficiency of optics in single-mode fiber
//cf    components", R. E. Wagner, W. J. Tomlison, august 1982, vol. 21,
//cf    No. 15, Applied Optic, p 2677 paragraph G. Results.
//cf
/*************************************************************************/
double coupl_eff_formula(complex **psy_p_S, double k ,  complex **W,
                         complex **psy_p_R,
                         struct bound_1D bound_x, struct bound_1D bound_y)
{
  double T; 

  int x, y;
  int m,n;
  complex i_cplx ;
  complex k_cplx ;

  i_cplx = complex(0,1);

  m = bound_x.num;
  n = bound_y.num;

  complex** integrant = cmatrix(n,m);
  if (!integrant)
     {
      cout<<"Error in dynamic memory allocation in function coupl_eff_formula\n";
      exit(1);
     }

  for (x=0;x<m;x++)
     {
      for (y=0;y<n;y++)  
         {
     integrant[x][y] = psy_p_S[x][y]
                      *exp(-i_cplx*k*W[x][y])
                      *psy_p_R[x][y];

         }
     }

  T = norm(dbl_cmplx_integral(integrant,bound_x,bound_y));


free(integrant);
   
  return(T);
}
//f

/// "dbl_cmplx_integral"
/*************************************************************************/
//cf
//cf  Name of the function        : dbl_cmplx_integral
//cf  Version                     : 0.3
//cf  Date of creation            : 16/06/1997 (Xavier)
//cf  Last modification on        : 22/07/1997 (Xavier)
//cf  Last correction on          : 22/07/1997 (Xavier)
//cf  Compatibility               : 1.0
//cf  Verification Stage          : (see below)
//cf  Description of the function : Compute a very simple double-integral 
//cf   of complex parameters.
//cf
/*************************************************************************/
complex dbl_cmplx_integral(complex **input_field, 
                           struct bound_1D bound_x, struct bound_1D bound_y)
{
  complex integr; 
  int x, y;
  int m,n;
  double d_surf;

  integr = complex(0.,0.); 

  m = bound_x.num;
  n = bound_y.num;

  d_surf = ((bound_x.max-bound_x.min)*(bound_y.max-bound_y.min))
           /(n*m);

  for (x=0;x<m;x++)
     {
      for (y=0;y<n;y++)  
         {
          integr += input_field[x][y];
         }
     }


  integr *= d_surf;

  return(integr);
}
//f

/// "power_field"
/*************************************************************************/
//cf
//cf  Name of the function        : norm_field
//cf  Version                     : 0.1
//cf  Date of creation            : 04/08/1997 (Xavier)
//cf  Last modification on        : 
//cf  Last correction on          : 
//cf  Compatibility               : 1.0
//cf  Verification Stage          : (see below)
//cf  Description of the function : Compute the total power of the field in
//cf    the windon used for calculations.
//cf
/*************************************************************************/
complex power_field(complex **input_field, 
                    struct bound_1D bound_x, struct bound_1D bound_y)
{
  complex power;
  int  x, y;
  int m,n;

  m = bound_x.num;
  n = bound_y.num;

  complex** matrix = cmatrix(m,n); 
  if (!matrix) 
     {
      cout<<"Error in dynamic memory allocation in function power_field\n";
      exit(1);
     }

  for (x=0;x<m;x++)
     {
      for (y=0;y<n;y++)
         {
         matrix[x][y] = input_field[x][y]*input_field[x][y];
         }
     }

  power = dbl_cmplx_integral(matrix,bound_x,bound_y);

  free(matrix);
   
  return (power);
 
}
//f

/// "normaliz_field"
/*************************************************************************/
//cf
//cf  Name of the function        : normaliz_field
//cf  Version                     : 0.2
//cf  Date of creation            : 16/06/1997 (Xavier)
//cf  Last modification on        : 22/07/1997 (Xavier)
//cf  Last correction on          : 31/07/1997 (Xavier)
//cf  Compatibility               : 1.0
//cf  Verification Stage          : (see below)
//cf  Description of the function : Normalize the input_field
//cf
/*************************************************************************/
void normaliz_field(complex **input_field, 
                    struct bound_1D bound_x, struct bound_1D bound_y)
{
  double absolut; 
  int  x, y;
  int m,n;

  m = bound_x.num;
  n = bound_y.num;

  complex** matrix = cmatrix(m,n); 
  if (!matrix) 
     {
      cout<<"Error in dynamic memory allocation in function normaliz_field\n";
      exit(1);
     }

  for (x=0;x<m;x++)
     {
      for (y=0;y<n;y++)
         {
         matrix[x][y] = input_field[x][y]*input_field[x][y];
         }
     }

  absolut = sqrt(abs(dbl_cmplx_integral(matrix,bound_x,bound_y)));

  for (x=0;x<bound_x.num;x++)
     {
      for (y=0;y<bound_y.num;y++)
         {
          input_field[x][y] /= absolut;
         }
     }

  free(matrix);
   
 
}
//f

/*************************************************************************/
//cl
//cl  End of file : coupl_eff.c++
//cl
/*************************************************************************/

//f
