
/// "params.c++"

/// "WARNING"
// **************************************************************************
// **************************************************************************
/*
                      SINGLE MODE OPTICAL FIBER COUPLING

     This program was thinked and realised by Xavier Outhier at the 
   Czech Thechnical University of Prague (Czech Republic) at the Faculty
   of Nuclear Physics in the department of Physical Electronics.

      This program was created in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

     Please contact me when you use it for your own and give me your
   impression about it (facility of use, bugs,...). Here is my e-mail
                      d2set@multimania.com
	  (precise in the subject or body of message to Xavier Outhier)
	      You can also visit the web site of D2SET association
		          http://www.multimania.com/d2set/


                                                Prague, 29th May 1997

                                                Xavier Outhier

*/
// **************************************************************************
// **************************************************************************
//f

/*************************************************************************/
//ce
//ce  NAME OF FILE            : params.c++
//ce  VERSION                 : 1.2
//ce  DATE OF CREATION        : 10/06/1997 (Xavier)
//ce  LAST MODIFICATION ON    : 29/07/1997 (Xavier)
//ce  LAST CORRECTION ON      : 
//ce  COMPATIBILITY           : 1.0
//ce  STAGE OF VERIFICATION   : none
//ce  DESCRIPTION OF THE FILE : Contains functions that compute parameters
//ce   such like waist of Gaussian mode of a monomode fiber, the divergence
//ce   angle of a Gaussian beam...
//ce
//ce  Transformation of the C file params.c in C++.
//ce
/*************************************************************************/

/*************************************************************************/
//cm
//cm  List  of modifications :
//cm
//cm   v1.1,, 23/07/1997, Xavier:
//cm    # Add of Snell_angle()
//cm    # Add of functions to compute relexion and transmission coefficient
//cm      for TE and TM polarization through a plane interface. These 
//cm      functions are: reflect_TE, reflect_TM, transm_TE() and transm_TM()
//cm
//cm   v1.2,, 29/07/1997, Xavier:
//cm    # Simplification of angl_fib_misalign
//cm
/*************************************************************************/

/*************************************************************************/
//cc
//cc  List  of corrections :
//cc
/*************************************************************************/

/// "includes"
#include <complex.h>
#include "params.h"
//f

/// "wf_Vstep_a"
/*************************************************************************/
//cf
//cf  Name of the function        : wf_Vstep_a
//cf  Version                     : 0.1
//cf  Date of creation            : 03/06/1997 (Xavier)
//cf  Last modification on        : 09/06/1997 (Xavier)
//cf  Last correction on          : 
//cf  Compatibility               : 1.0
//cf  Verification Stage          : (see below)
//cf    compilation with cc -c -fullwarn -Xcpluscomm ---------------> OK
//cf    linkage avec -lm -------------------------------------------> OK
//cf    execution et passage parametres ----------------------------> OK
//cf  Description of the function : Compute the length of the fundamental
//cf    mode of propagation of a single mode fiber. Variable is V the 
//cf    normalised frequency and a the radius of the fiber core. The fiber 
//cf    is supposed being a step index one. Formula from "Loss Analysis of
//cf    Single-Mode Fiber Splices", D. Marcuse, The Bell Syst. Tech. J., 
//cf    May-June 1977, p706.
//cf
/*************************************************************************/
double wf_Vstep_a(double Vstep, double a)
{
  double output; 

  output = a*(0.65 + (1.619*pow(Vstep,-1.5)) + (2.879*pow(Vstep,-6.)) );

  return(output);
}
//f

/// "wf_Vparab_a"
/*************************************************************************/
//cf
//cf  Name of the function        : wf_Vparab_a
//cf  Version                     : 0.1
//cf  Date of creation            : 09/06/1997 (Xavier)
//cf  Last modification on        :
//cf  Last correction on          : 
//cf  Compatibility               : 1.0
//cf  Verification Stage          : (see below)
//cf    compilation with cc -c -fullwarn -Xcpluscomm ---------------> OK
//cf    linkage avec -lm -------------------------------------------> OK
//cf    execution et passage parametres ----------------------------> OK
//cf  Description of the function : Compute the length of the fundamental
//cf    mode of propagation of a single mode fiber. Variable is V the 
//cf    normalised frequency and a the radius of the fiber core. The fiber 
//cf    is supposed being a parabolic index one. Formula from "Loss Analysis
//cf    of Single-Mode Fiber Splices", D. Marcuse, The Bell Syst. Tech. J., 
//cf    May-June 1977, p712.
//cf
/*************************************************************************/
double wf_Vparab_a(double Vparab, double a)
{
  double output; 
 
  output = a*((M_SQRT2*pow(Vparab,-0.5)) + (0.23*pow(Vparab,-1.5)) 
              + (18.01*pow(Vparab,-6.)) );

  return(output);
}
//f

/// "wf_lnna"
/*************************************************************************/
//cf
//cf  Name of the function        : wf_lnna
//cf  Version                     : 0.1
//cf  Date of creation            : 03/06/1997 (Xavier)
//cf  Last modification on        :
//cf  Last correction on          : 02/07/1997 (Xavier)
//cf  Compatibility               : 1.0
//cf  Verification Stage          : none
//cf  Description of the function : Compute the length of the fundamental
//cf    mode of propagation of a single mode fiber. Variables are lambda
//cf    the length wave, ncore and nclad the refractives index of the core
//cf    and of tha cladding of the fiber and a the radius of the fiber core.
//cf
/*************************************************************************/
double wf_lnna(double lambda, double ncore, double nclad, double a)
{
  double output,V2; 

  V2 = pow(2.*M_PI/lambda*a,2.)*(ncore-nclad)*(ncore+nclad);

  output = a*(0.65 + (1.619/pow(V2,0.75)) + (2.879/pow(V2,3.)) );

  return(output);
}
//f

/// "w_gauss"
/*************************************************************************/
//cf
//cf  Name of the function        : w_gauss
//cf  Version                     : 0.1
//cf  Date of creation            : 04/07/1997 (Xavier)
//cf  Last modification on        :
//cf  Last correction on          : 
//cf  Compatibility               : 1.0
//cf  Verification Stage          : (see below)
//cf    compilation with cc -c -fullwarn -Xcpluscomm ---------------> OK
//cf    linkage avec -lm -------------------------------------------> OK
//cf    execution et passage parametres ----------------------------> OK
//cf  Description of the function : Compute the length of the fundamental
//cf    gaussian beam at a distance "z"qrt(z2) of the waist "w0". "zR" is
//cf    the Rayleigh distance.
//cf
/*************************************************************************/
double w_gauss(double z2, double w0, double zR)
{
  double output; 

  output = w0*sqrt(1. + z2/(zR*zR));

  return(output);
}
//f

/// "z_R"
/*************************************************************************/
//cf
//cf  Name of the function        : z_R
//cf  Version                     : 0.1
//cf  Date of creation            : 03/06/1997 (Xavier)
//cf  Last modification on        :
//cf  Last correction on          : 
//cf  Compatibility               : 1.0
//cf  Verification Stage          : (see below)
//cf    compilation with cc -c -fullwarn -Xcpluscomm ---------------> OK
//cf    linkage avec -lm -------------------------------------------> OK
//cf    execution et passage parametres ----------------------------> OK
//cf  Description of the function : Compute Rayleigh distance in function of
//cf   n_medium of the refractive index of the medium, lambda the wave length
//cf   and of the waist of the beam wG.
//cf
/*************************************************************************/
double z_R(double n_medium, double lambda, double wG)
{
  double output; 

  output = M_PI*n_medium*wG*wG/lambda;

  return(output);
}
//f

/// "V_norm"
/*************************************************************************/
//cf
//cf  Name of the function        : V_norm
//cf  Version                     : 0.1
//cf  Date of creation            : 06/06/1997 (Xavier)
//cf  Last modification on        : 09/06/1997 (Xavier)
//cf  Last correction on          : 02/07/1997 (Xavier)
//cf  Compatibility               : 1.0
//cf  Verification Stage          : (see below)
//cf    compilation with cc -c -fullwarn -Xcpluscomm ---------------> OK
//cf    linkage avec -lm -------------------------------------------> OK
//cf    execution et passage parametres ----------------------------> OK
//cf  Description of the function : Compute normalized frequence in function
//cf   of n_core of the refractive index of the core, n_clad the refractive
//cf   index of the cladding, lambda the wave length and a the radius of
//cf   the fiber core. 
//cf
/*************************************************************************/
double V_norm(double n_core, double n_clad , double lambda, double a)
{
  double output; 

  output = 2.*M_PI/lambda*a*sqrt(n_core*n_core - n_clad*n_clad);

  return(output);
}
//f

/// "Snell_angle"
/*************************************************************************/
//cf
//cf  Name of the function        : Snell_angle
//cf  Version                     : 0.1
//cf  Date of creation            : 23/07/1997 (Xavier)
//cf  Last modification on        : 
//cf  Last correction on          : 
//cf  Compatibility               : 1.0
//cf  Verification Stage          : (see below)
//cf    compilation with cc -c -fullwarn -Xcpluscomm ---------------> OK
//cf    linkage avec -lm -------------------------------------------> OK
//cf    execution et passage parametres ----------------------------> OK
//cf  Description of the function : Compute the angle theta2 of a planar
//cf   wave coming through the planar interface with an angle theta1. The
//cf   angle are mesure from the normal to the interface. The refractive 
//cf   index of the two media are respectively n1 and n2.
//cf
//cf   The angles are mesured in radians!!!
//cf
//cf Reference: Zakladny fotoniky, B. E. A. Saleh and M. C. Teich,
//cf  matfyzpress, volume 2, page 240.
//cf
/*************************************************************************/
double Snell_angle(double n1, double n2 , double theta1)
{
  double theta2;
  double sintheta2;

  sintheta2 = (n1/n2)*sin(theta1);

  if (sintheta2 > 1.) {return(M_PI_2);}

  theta2 = asin(sintheta2);

  return(theta2);
}
//f
/// "reflect_TE"
/*************************************************************************/
//cf
//cf  Name of the function        : reflect_TE
//cf  Version                     : 0.1
//cf  Date of creation            : 23/07/1997 (Xavier)
//cf  Last modification on        : 
//cf  Last correction on          : 
//cf  Compatibility               : 1.0
//cf  Verification Stage          : (see below)
//cf    compilation with cc -c -fullwarn -Xcpluscomm ---------------> OK
//cf    linkage avec -lm -------------------------------------------> OK
//cf    execution et passage parametres ----------------------------> OK
//cf  Description of the function : Compute reflection coefficient of the
//cf   elctric field E through a planar interface separating two media of
//cf   respectiverly index n1 and n2. E is TE polarized i.e. its
//cf   direction of polarization is parallel to the interface. The incoming
//cf   direction of the light in medium n1 is theta1 (it's the angle of
//cf   the vector wave k1 and the normal to the interface), in the 
//cf   second medium it'a theta2. These angles are available bye the 
//cf   Snell-Descartes law.
//cf
//cf   The angles are mesured in radians!!!
//cf
//cf Reference: Zakladny fotoniky, B. E. A. Saleh and M. C. Teich,
//cf  matfyzpress, volume 2, page 240.
//cf
/*************************************************************************/
double reflect_TE(double n1, double n2 , double theta1, double theta2)
{
  double rx; 
  double cos1, cos2;
  
  cos1 = cos(theta1);
  cos2 = cos(theta2);

  rx = (n1*cos1 - n2*cos2)/(n1*cos1 + n2*cos2);

  return(rx);
}
//f

/// "reflect_TM"
/*************************************************************************/
//cf
//cf  Name of the function        : reflect_TM
//cf  Version                     : 0.1
//cf  Date of creation            : 23/07/1997 (Xavier)
//cf  Last modification on        : 
//cf  Last correction on          : 
//cf  Compatibility               : 1.0
//cf  Verification Stage          : (see below)
//cf    compilation with cc -c -fullwarn -Xcpluscomm ---------------> OK
//cf    linkage avec -lm -------------------------------------------> OK
//cf    execution et passage parametres ----------------------------> OK
//cf  Description of the function : Compute reflection coefficient of the
//cf   elctric field E through a planar interface separating two media of
//cf   respectiverly index n1 and n2. E is TM polarized i.e. the magnetique 
//cf   field B has its direction of polarization parallel to the interface. 
//cf   The incoming direction of the light in medium n1 is theta1 (it's the 
//cf   angle of the vector wave k1 and the normal to the interface), in the 
//cf   second medium it'a theta2. These angles are available bye the 
//cf   Snell-Descartes law.
//cf
//cf   The angles are mesured in radians!!!
//cf
//cf Reference: Zakladny fotoniky, B. E. A. Saleh and M. C. Teich,
//cf  matfyzpress, volume 2, page 240.
//cf
/*************************************************************************/
double reflect_TM(double n1, double n2 , double theta1, double theta2)
{
  double ry; 
  double cos1, cos2;
  
  cos1 = cos(theta1);
  cos2 = cos(theta2);

  ry = (n2*cos1 - n1*cos2)/(n2*cos1 + n1*cos2);

  return(ry);
}
//f

/// "transm_TE"
/*************************************************************************/
//cf
//cf  Name of the function        : transm_TE
//cf  Version                     : 0.1
//cf  Date of creation            : 23/07/1997 (Xavier)
//cf  Last modification on        : 
//cf  Last correction on          : 
//cf  Compatibility               : 1.0
//cf  Verification Stage          : (see below)
//cf    compilation with cc -c -fullwarn -Xcpluscomm ---------------> OK
//cf    linkage avec -lm -------------------------------------------> OK
//cf    execution et passage parametres ----------------------------> OK
//cf  Description of the function : Compute transmition coefficient of the
//cf   elctric field E through a planar interface separating two media of
//cf   respectiverly index n1 and n2. E is TM polarized i.e. its
//cf   direction of polarization parallel to the interface. 
//cf   The incoming direction of the light in medium n1 is theta1 (it's the 
//cf   angle of the vector wave k1 and the normal to the interface), in the 
//cf   second medium it'a theta2. These angles are available bye the 
//cf   Snell-Descartes law.
//cf
//cf   The angles are mesured in radians!!!
//cf
//cf Reference: Zakladny fotoniky, B. E. A. Saleh and M. C. Teich,
//cf  matfyzpress, volume 2, page 240.
//cf
/*************************************************************************/
double transm_TE(double n1, double n2 , double theta1, double theta2)
{
  double rx,tx; 

  rx = reflect_TM(n1,n2,theta1,theta2);
  tx = 1. + rx;

  return(tx);
}
//f

/// "transm_TM"
/*************************************************************************/
//cf
//cf  Name of the function        : transm_TM
//cf  Version                     : 0.1
//cf  Date of creation            : 23/07/1997 (Xavier)
//cf  Last modification on        : 
//cf  Last correction on          : 
//cf  Compatibility               : 1.0
//cf  Verification Stage          : (see below)
//cf    compilation with cc -c -fullwarn -Xcpluscomm ---------------> OK
//cf    linkage avec -lm -------------------------------------------> OK
//cf    execution et passage parametres ----------------------------> OK
//cf  Description of the function : Compute transmition coefficient of the
//cf   elctric field E through a planar interface separating two media of
//cf   respectiverly index n1 and n2. E is TM polarized i.e. the magnetique 
//cf   field B has it's direction of polarization parallel to the interface. 
//cf   The incoming direction of the light in medium n1 is theta1 (it's the 
//cf   angle of the vector wave k1 and the normal to the interface), in the 
//cf   second medium it'a theta2. These angles are available bye the 
//cf   Snell-Descartes law.
//cf
//cf   The angles are mesured in radians!!!
//cf
//cf Reference: Zakladny fotoniky, B. E. A. Saleh and M. C. Teich,
//cf  matfyzpress, volume 2, page 240.
//cf
/*************************************************************************/
double transm_TM(double n1, double n2 , double theta1, double theta2)
{
  double ry,ty; 

  ry = reflect_TM(n1,n2,theta1,theta2);
  ty = n1/n2*(1. + ry);

  return(ty);
}
//f

/// "reflect_power_coef"
/*************************************************************************/
//cf
//cf  Name of the function        : reflect_power_coef
//cf  Version                     : 0.1
//cf  Date of creation            : 23/07/1997 (Xavier)
//cf  Last modification on        : 
//cf  Last correction on          : 
//cf  Compatibility               : 1.0
//cf  Verification Stage          : (see below)
//cf    compilation with cc -c -fullwarn -Xcpluscomm ---------------> OK
//cf    linkage avec -lm -------------------------------------------> OK
//cf    execution et passage parametres ----------------------------> OK
//cf  Description of the function : Compute transmition coefficient of the
//cf   power through a planar interface that separates 2 media of refractive
//cf   index n1 and n2. The incoming wave is supposed planar, homogenous and
//cf   normally incident.
//cf
//cf References: 
//cf  Single-Mode Fibers, Fundamentals, E.-G. Neumann, Springer-Verlag
//cf   p 174.
//cf  Zakladny fotoniky, B. E. A. Saleh and M. C. Teich,matfyzpress, 
//cf   volume 2, page 240.
//cf
/*************************************************************************/
double reflect_power_coef(double n1, double n2)
{
  double coef_p, coef_f;

// reflection coeficient of the field
  coef_f = (n1 - n2)/(n1 + n2);

// reflection coeficient of the power or intensity
  coef_p = 1. - pow(coef_f,2.);

  return(coef_p);
}
//f


/// "coef_lin_fib_misalign"
/*************************************************************************/
//cf
//cf  Name of the function        : coef_lin_fib_misalign
//cf  Version                     : 0.1
//cf  Date of creation            : 19/06/1997 (Xavier)
//cf  Last modification on        :
//cf  Last correction on          : 11/07/1997 (Xavier)
//cf  Compatibility               : 1.0
//cf  Verification Stage          : (see below)
//cf    compilation and linkage with makefile ----------------------> OK
//cf    execution et passage parametres ----------------------------> OK
//cf  Description of the function : Compute coefficients W_1x, W_1y and W_20
//cf    due to a linear fiber misalignment from lateral shfit (delta_x,
//cf    delta_y) and longitudinal offset delta_R_p, R_p. 
//cf
//cf    Unnormalized formula (12) from "Coupling efficiency of optics in 
//cf    single-mode fiber components", R. E. Wagner, W. J. Tomlison, 
//cf    August 1982, vol. 21, No. 15, Applied Optic, p 2679.
//cf
/*************************************************************************/
void coef_lin_fib_misalign(double delta_x, double delta_y,
                           double R_p, double delta_R_p,
                           double *W_1x, double *W_1y, double *W_20)
{

  *W_1x = delta_x/R_p;
  *W_1y = delta_y/R_p;
  *W_20 = delta_R_p/(2.*R_p*R_p);

  return ;
}
//f

/// "angl_fib_misalign"
/*************************************************************************/
//cf
//cf  Name of the function        : amgl_fib_misalign
//cf  Version                     : 0.3
//cf  Date of creation            : 20/06/1997 (Xavier)
//cf  Last modification on        : 29/07/1997 (Xavier)
//cf  Last correction on          :
//cf  Compatibility               : 1.0
//cf  Verification Stage          : (see below)
//cf    compilation and linkage with makefile ----------------------> OK
//cf    execution et passage parametres ----------------------------> OK
//cf  Description of the function : Compute normalized exit-pupil shifts
//cf    (x0,y0) corresponding to angular misalignment (d_theta_x, d_theta_y).
//cf
//cf    Unnormalized formula (15) from "Coupling efficiency of optics in 
//cf    single-mode fiber components", R. E. Wagner, W. J. Tomlison, 
//cf    August 1982, vol. 21, No. 15, Applied Optic, p 2679.
//cf
/*************************************************************************/
void angl_fib_misalign(double sind_theta_x, double sind_theta_y,
                       double R_p, double *x0, double *y0)
{

  *x0 = sind_theta_x*R_p;
  *y0 = sind_theta_y*R_p;

  return ;
}
//f


/*************************************************************************/
//cl
//cl  End of file : params.c++
//cl
/*************************************************************************/

//f

